local assets=
{
	Asset("ANIM", "anim/rocks.zip"),
	Asset("ANIM", "anim/swap_rocks.zip"),
}

local names = {"f1","f2","f3"}

local function onsave(inst, data)
	data.anim = inst.animname
end

local function onload(inst, data)
    if data and data.anim then
        inst.animname = data.anim
	    inst.AnimState:PlayAnimation(inst.animname)
	end
end

local function OnThrown(inst, owner, target)
    if target ~= owner then
        owner.SoundEmitter:PlaySound("dontstarve/common/stone_drop")
    end
end

local function OnEquip(inst, owner) 
    owner.AnimState:OverrideSymbol("swap_object", "swap_rocks", "swap_diviningrod")
    owner.AnimState:Show("ARM_carry") 
    owner.AnimState:Hide("ARM_normal") 
end

local function OnDropped(inst)
    inst.AnimState:PlayAnimation("idle")
end

local function OnUnequip(inst, owner) 
    owner.AnimState:Hide("ARM_carry") 
    owner.AnimState:Show("ARM_normal") 
end

local function OnHit(inst, owner, target)
    if owner == target then
        OnDropped(inst)
    else
	    local pt = Point(inst.Transform:GetWorldPosition())
        local breaking = SpawnPrefab("ground_chunks_breaking")
		breaking.Transform:SetPosition(pt.x, 0, pt.z)
		inst:Remove()
    end
    local impactfx = SpawnPrefab("impact")
    if impactfx then
	    local follower = impactfx.entity:AddFollower()
	    follower:FollowSymbol(target.GUID, target.components.combat.hiteffectsymbol, 0, 0, 0 )
        impactfx:FacePoint(Vector3(inst.Transform:GetWorldPosition()))
    end
end

local function fn(Sim)
	local inst = CreateEntity()
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    MakeInventoryPhysics(inst)
	
	local player = GetPlayer()
	if player and player.prefab=="toph" then
	    inst:AddTag("projectile")
	    inst:AddTag("thrown")
	
	    inst:AddComponent("projectile")
	    inst.components.projectile:SetSpeed(25)
	    inst.components.projectile:SetCanCatch(false)
	    inst.components.projectile:SetHoming(true)
	    inst.components.projectile:SetOnThrownFn(OnThrown)
	    inst.components.projectile:SetOnHitFn(OnHit)
	
	    inst:AddComponent("equippable")
	    inst.components.equippable:SetOnEquip(OnEquip)
	    inst.components.equippable:SetOnUnequip(OnUnequip)
	    inst.components.equippable.equipstack = true
	
	    inst:AddComponent("weapon")
	    inst.components.weapon:SetDamage(TUNING.BOOMERANG_DAMAGE * 2)
	    inst.components.weapon:SetRange(TUNING.BOOMERANG_DISTANCE*.9, .9*TUNING.BOOMERANG_DISTANCE+2)
	end

    inst.AnimState:SetBank("rocks")
    inst.AnimState:SetBuild("rocks")
    inst.animname = names[math.random(#names)]
    inst.AnimState:PlayAnimation(inst.animname)

    inst:AddComponent("edible")
    inst.components.edible.foodtype = "ELEMENTAL"
    inst.components.edible.hungervalue = 1
    inst:AddComponent("tradable")
	
    inst:AddComponent("stackable")
	inst.components.stackable.maxsize = TUNING.STACK_SIZE_SMALLITEM
    
    inst:AddComponent("inspectable")
    
    inst:AddComponent("inventoryitem")

	inst:AddComponent("repairer")
	inst.components.repairer.repairmaterial = "stone"
	inst.components.repairer.value = TUNING.REPAIR_ROCKS
	
    inst.OnSave = onsave 
    inst.OnLoad = onload 
    return inst
end

return Prefab( "common/inventory/rocks", fn, assets) 
